window.Gleam.initSearch([{"doc":"glatch","title":"glatch","content":"# glatch\n\n[![Package Version](https://img.shields.io/hexpm/v/glatch)](https://hex.pm/packages/glatch)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glatch/)\n\n![logo](logo.jpg)\n\nGleam type check using pattern matching\n\n```sh\ngleam add glatch\n```\n\n\n```gleam\nimport glatch.{IsString}\nimport gleam/string\n\npub fn main() {\n  case glatch.get_type(&quot;Lucy&quot;) {\n    IsString(_) -&gt; &quot;Hello, 𓇼&quot;\n    unknown -&gt; &quot;Who are you? &quot; &lt;&gt; string.inspect(unknown)\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glatch&gt;.\n\n## Current status\n\n#### Native / Stdlib\n\n- [x] String\n- [x] Int\n- [x] Float\n- [x] Bool\n- [x] List\n  - [x] nested type check\n  - [x] empty type check\n- [x] Option\n  - [x] Some type check\n  - [x] None type check  \n- [x] Result\n  - [x] Ok type check\n  - [x] Error type check  \n- [x] Dict\n  - [x] key type check\n  - [x] value type check\n  - [x] empty type check \n- [x] Tuple\n  - [x] Arity 0-6 \n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"glatch","title":"MatchedType","content":"pub type MatchedType(x) {\n  IsInt(Int)\n  IsString(String)\n  IsBool(Bool)\n  IsFloat(Float)\n  IsList(MatchedType(x))\n  IsOption(Option(MatchedType(x)))\n  IsResult(Result(MatchedType(x), MatchedType(x)))\n  IsDict(MatchedType(x), MatchedType(x))\n  IsTuple0\n  IsTuple1(MatchedType(x))\n  IsTuple2(MatchedType(x), MatchedType(x))\n  IsTuple3(MatchedType(x), MatchedType(x), MatchedType(x))\n  IsTuple4(\n    MatchedType(x),\n    MatchedType(x),\n    MatchedType(x),\n    MatchedType(x),\n  )\n  IsTuple5(\n    MatchedType(x),\n    MatchedType(x),\n    MatchedType(x),\n    MatchedType(x),\n    MatchedType(x),\n  )\n  IsTuple6(\n    MatchedType(x),\n    MatchedType(x),\n    MatchedType(x),\n    MatchedType(x),\n    MatchedType(x),\n    MatchedType(x),\n  )\n  IsNotFound\n  IsEmpty\n}\n\nIsInt(Int)\n\n\nIsString(String)\n\n\nIsBool(Bool)\n\n\nIsFloat(Float)\n\n\nIsList(MatchedType(x))\n\n\nIsOption(Option(MatchedType(x)))\n\n\nIsResult(Result(MatchedType(x), MatchedType(x)))\n\n\nIsDict(MatchedType(x), MatchedType(x))\n\n\nIsTuple0\n\n\nIsTuple1(MatchedType(x))\n\n\nIsTuple2(MatchedType(x), MatchedType(x))\n\n\nIsTuple3(MatchedType(x), MatchedType(x), MatchedType(x))\n\n\nIsTuple4(\n  MatchedType(x),\n  MatchedType(x),\n  MatchedType(x),\n  MatchedType(x),\n)\n\n\nIsTuple5(\n  MatchedType(x),\n  MatchedType(x),\n  MatchedType(x),\n  MatchedType(x),\n  MatchedType(x),\n)\n\n\nIsTuple6(\n  MatchedType(x),\n  MatchedType(x),\n  MatchedType(x),\n  MatchedType(x),\n  MatchedType(x),\n  MatchedType(x),\n)\n\n\nIsNotFound\n\n\nIsEmpty\n\n\nSynonyms:\nglatch.MatchedType\nglatch MatchedType","url":"glatch.html#MatchedType"},{"doc":"glatch","title":"get_type","content":"pub fn get_type(item: a) -&gt; MatchedType(b)\n\nSynonyms:\nglatch.get_type\nglatch get_type","url":"glatch.html#get_type"},{"doc":"glatch","title":"glatch","content":"","url":"glatch.html"}]);